# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	A C library for portable packet creation and injection
Name:		libnet
Version:	1.1.5
Release:	3.0.cf.%{__distinit}%{__distvers}
License:	BSD
Group:		System Environment/Libraries
URL:		http://sourceforge.net/projects/libnet-dev/
Source:		http://downloads.sf.net/libnet-dev/libnet-%{version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	symlinks

%description
Libnet is an API to help with the construction and handling of network
packets. It provides a portable framework for low-level network packet
writing and handling (use libnet in conjunction with libpcap and you can
write some really cool stuff). Libnet includes packet creation at the IP
layer and at the link layer as well as a host of supplementary and
complementary functionality.

%package devel
Summary:	Development files for the libnet library
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
The libnet-devel package includes header files and libraries necessary
for developing programs which use the libnet library. Libnet is very handy
with which to write network tools and network test code. See the manpage
and sample test code for more detailed information.

%prep
%setup -q

%build
%configure --libdir=/%{_lib}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Move libnet.so to %%{_libdir}
mkdir -p %{buildroot}%{_libdir}
rm %{buildroot}/%{_lib}/libnet.so
ln -s %{buildroot}/%{_lib}/libnet.so.*.*.* %{buildroot}%{_libdir}/libnet.so
symlinks -cs %{buildroot}%{_libdir}

# Fix up header file inclusion in sample code
sed -e 's|#include "../include/libnet.h"|#include <libnet.h>|' \
	sample/libnet_test.h > sample/libnet_test.h.new
touch -c -r sample/libnet_test.h{,.new}
mv -f sample/libnet_test.h{.new,}

# Discard stuff we don't want packaged
rm %{buildroot}/%{_lib}/libnet.{a,la}
make -C sample clean
rm -rf sample/{win32,Makefile.{am,in}}
rm -f doc/html/Makefile*

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README doc/CHANGELOG doc/CONTRIB doc/COPYING
/%{_lib}/libnet.so.*

%files devel
%defattr(-,root,root,-)
%doc doc/BUGS doc/DESIGN_NOTES doc/MIGRATION doc/PACKET_BUILDING
%doc doc/RAWSOCKET_NON_SEQUITUR doc/TODO doc/html/ sample/
%{_bindir}/libnet-config
%{_libdir}/libnet.so
%{_includedir}/libnet.h
%{_includedir}/libnet/
%{_mandir}/man3/libnet-functions.h.3*
%{_mandir}/man3/libnet-macros.h.3*
%{_mandir}/man3/libnet.h.3*

%changelog
* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> - 1.1.5-3.0.cf
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.1.5-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 31 2010 Paul Howarth <paul@city-fan.org> - 1.1.5-1.0.cf
- Updated to 1.1.5 (see CHANGELOG for details)

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.1.4-5.0.cf
- Fix dist tag for RHEL-6 Beta

* Wed Feb 24 2010 Paul Howarth <paul@city-fan.org> - 1.1.4-4.0.cf
- Dist tag for Rawhide no longer needs special-casing

* Thu Aug 27 2009 Paul Howarth <paul@city-fan.org> - 1.1.4-3.0.cf
- Updated to 1.1.4
- Add dist tags
- Clean out old cruft
- Upstream development now at http://sourceforge.net/projects/libnet-dev/
- Split off -devel subpackage
- Install into /%%{_lib} for benefit of syslog type apps (#518150)
- Enable parallel build
- Maintain timestamps of untouched upstream files
- Add scriptlets to run ldconfig since the library is now shared, not static
- Add buildreq symlinks
- Fix header file location in sample code

* Mon Sep 20 2004 Paul Howarth <paul@city-fan.org> - 1.1.2.1
- Rewritten for 1.1.2.1

* Mon Dec 16 2002 Dag Wieers <dag@wieers.com> - 1.0.2
- Updated to 1.0.2a (1.1.0 does not work with 1.1.0)

* Thu Aug 02 2001 Dag Wieers <dag@wieers.com> - 1.0.1
- Initial package
